@@ -1,5 +1,5 @@
 /*
- *  Copyright 2005,2006 Fabrice Colin
+ *  Copyright 2005-2009 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 #ifndef _LANGUAGE_DETECTOR_H
 #define _LANGUAGE_DETECTOR_H
 
+#include <pthread.h>
 #include <string>
 #include <vector>
 
@@ -26,9 +27,10 @@
 class LanguageDetector
 {
 	public:
-		LanguageDetector();
 		virtual ~LanguageDetector();
 
+		static LanguageDetector &getInstance(void);
+
 		/**
 		  * Attempts to guess the language.
 		  * Returns a list of candidates, or "unknown" if detection failed.
@@ -37,7 +39,11 @@ class LanguageDetector
 			std::vector<std::string> &candidates);
 
 	protected:
-		static unsigned int m_maxTextSize;
+		static LanguageDetector m_instance;
+		pthread_mutex_t m_mutex;
+		void *m_pHandle;
+
+		LanguageDetector();
 
 	private:
 		LanguageDetector(const LanguageDetector &other);
