@@ -1,5 +1,5 @@
 /*
- *  Copyright 2005-2012 Fabrice Colin
+ *  Copyright 2005-2013 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -164,7 +164,7 @@ class TokensIndexer : public Dijon::CJKVTokenizer::TokensHandler
 				bool hasDiacritics = false;
 
 				// Remove accents and other diacritics
-				string unaccentedTerm(StringManip::stripDiacritics(term));
+				string unaccentedTerm(Dijon::CJKVTokenizer::strip_marks(term));
 				if (unaccentedTerm != term)
 				{
 					m_doc.add_posting(m_prefix + XapianDatabase::limitTermLength(unaccentedTerm), m_termPos);
@@ -632,7 +632,22 @@ void XapianIndex::addCommonTerms(const DocumentInfo &docInfo, Xapian::Document &
 	if (title.empty() == false)
 	{
 		addPostingsToDocument(Xapian::Utf8Iterator(title), doc, db, "S",
-			true, m_doSpelling, termPos);
+			false, m_doSpelling, termPos);
+	}
+
+	string hostName, tree, fileName;
+
+	if (g_pMapper != NULL)
+	{
+		hostName = g_pMapper->getHost(docInfo);
+		tree = g_pMapper->getDirectory(docInfo);
+		fileName = g_pMapper->getFile(docInfo);
+	}
+	else
+	{
+		hostName = StringManip::toLowerCase(urlObj.getHost());
+		tree = urlObj.getLocation();
+		fileName = urlObj.getFile();
 	}
 
 	// Index the full URL with prefix U
@@ -655,7 +670,6 @@ void XapianIndex::addCommonTerms(const DocumentInfo &docInfo, Xapian::Document &
 		}
 	}
 	// ...the host name and included domains with prefix H
-	string hostName(StringManip::toLowerCase(urlObj.getHost()));
 	if (hostName.empty() == false)
 	{
 		doc.add_term(string("H") + XapianDatabase::limitTermLength(hostName, true));
@@ -669,7 +683,6 @@ void XapianIndex::addCommonTerms(const DocumentInfo &docInfo, Xapian::Document &
 		}
 	}
 	// ...the location (as is) and all directories with prefix XDIR:
-	string tree(urlObj.getLocation());
 	if (tree.empty() == false)
 	{
 		doc.add_term(string("XDIR:") + XapianDatabase::limitTermLength(Url::escapeUrl(tree), true));
@@ -696,7 +709,6 @@ void XapianIndex::addCommonTerms(const DocumentInfo &docInfo, Xapian::Document &
 		doc.add_term("XDIR:/");
 	}
 	// ...and the file name with prefix P
-	string fileName(urlObj.getFile());
 	if (fileName.empty() == false)
 	{
 		string extension;
@@ -769,7 +781,7 @@ void XapianIndex::removeCommonTerms(Xapian::Document &doc, const Xapian::Writabl
 	if (title.empty() == false)
 	{
 		removePostingsFromDocument(Xapian::Utf8Iterator(title), doc, db, "S",
-			true, m_doSpelling);
+			false, m_doSpelling);
 	}
 
 	// Location 
