@@ -1,5 +1,5 @@
 /*
- *  Copyright 2008 Fabrice Colin
+ *  Copyright 2008-2013 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #define _SQL_DB_H
 
 #include <string>
+#include <vector>
 
 /// A row in a table.
 class SQLRow
@@ -44,7 +45,7 @@ class SQLResults
 	public:
 		virtual ~SQLResults();
 
-		bool hasMoreRows(void) const;
+		virtual bool hasMoreRows(void) const;
 
 		virtual std::string getColumnName(unsigned int nColumn) const = 0;
 
@@ -52,6 +53,10 @@ class SQLResults
 
 		virtual bool rewind(void);
 
+		virtual int getIntCount(void);
+
+		virtual off_t getOffsetCount(void);
+
 	protected:
 		unsigned long m_nRows;
 		unsigned int m_nColumns;
@@ -71,20 +76,34 @@ class SQLDB
 	public:
 		virtual ~SQLDB();
 
+		virtual bool isReadOnly(void) const;
+
 		virtual bool isOpen(void) const = 0;
 
 		virtual bool alterTable(const std::string &tableName,
 			const std::string &columns,
 			const std::string &newDefinition) = 0;
 
+		virtual bool beginTransaction(void) = 0;
+
+		virtual bool endTransaction(void) = 0;
+
 		virtual bool executeSimpleStatement(const std::string &sql) = 0;
 
 		virtual SQLResults *executeStatement(const char *sqlFormat, ...) = 0;
 
+		virtual bool prepareStatement(const std::string &statementId,
+			const std::string &sqlFormat) = 0;
+
+		virtual SQLResults *executePreparedStatement(const std::string &statementId,
+			const std::vector<std::string> &values) = 0;
+
 	protected:
 		std::string m_databaseName;
+		bool m_readOnly;
 
-		SQLDB(const std::string &databaseName);
+		SQLDB(const std::string &databaseName,
+			bool readOnly = false);
 
 	private:
 		SQLDB(const SQLDB &other);
