@@ -46,17 +46,9 @@ FileOutputFilter::~FileOutputFilter()
 
 bool FileOutputFilter::read_file(int fd, ssize_t maxSize, ssize_t &totalSize)
 {
-	struct stat fdStats;
 	ssize_t bytesRead = 0;
 	bool gotOutput = true;
 
-#ifdef DEBUG
-	if (fstat(fd, &fdStats) == 0)
-	{
-		clog << "FileOutputFilter::read_file: file size " << fdStats.st_size << endl;
-	}
-#endif
-
 	do
 	{
 		if ((maxSize > 0) &&
