@@ -1,5 +1,5 @@
 /*
- *  Copyright 2005-2009 Fabrice Colin
+ *  Copyright 2005-2012 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -63,14 +63,22 @@ ResultsTree::ResultsTree(const ustring &queryName, Menu *pPopupMenu,
 
 	// This is the actual results tree
 	set_events(Gdk::BUTTON_PRESS_MASK);
+#if GTK_VERSION_LT(3, 0)
 	set_flags(CAN_FOCUS);
+#else
+	set_can_focus();
+#endif
 	set_headers_clickable(true);
 	set_headers_visible(true);
 	set_rules_hint(true);
 	set_reorderable(false);
 	set_enable_search(true);
 	get_selection()->set_mode(SELECTION_MULTIPLE);
+#if GTK_VERSION_LT(3, 0)
 	m_pResultsScrolledwindow->set_flags(CAN_FOCUS);
+#else
+	m_pResultsScrolledwindow->set_can_focus();
+#endif
 	m_pResultsScrolledwindow->set_border_width(4);
 	m_pResultsScrolledwindow->set_shadow_type(SHADOW_NONE);
 	m_pResultsScrolledwindow->set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC);
@@ -78,7 +86,11 @@ ResultsTree::ResultsTree(const ustring &queryName, Menu *pPopupMenu,
 	m_pResultsScrolledwindow->add(*this);
 
 	// That's for the extract view
+#if GTK_VERSION_LT(3, 0)
 	m_extractTextView->set_flags(CAN_FOCUS);
+#else
+	m_extractTextView->set_can_focus();
+#endif
 	m_extractTextView->set_editable(false);
 	m_extractTextView->set_cursor_visible(false);
 	m_extractTextView->set_pixels_above_lines(0);
@@ -96,7 +108,11 @@ ResultsTree::ResultsTree(const ustring &queryName, Menu *pPopupMenu,
 	{
 		refBuffer->get_tag_table()->add(refBoldTag); 
 	}
+#if GTK_VERSION_LT(3, 0)
 	m_pExtractScrolledwindow->set_flags(CAN_FOCUS);
+#else
+	m_pExtractScrolledwindow->set_can_focus();
+#endif
 	m_pExtractScrolledwindow->set_border_width(4);
 	m_pExtractScrolledwindow->set_shadow_type(SHADOW_NONE);
 	m_pExtractScrolledwindow->set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC);
@@ -174,13 +190,24 @@ ResultsTree::ResultsTree(const ustring &queryName, Menu *pPopupMenu,
 	// Control which rows can be selected
 	get_selection()->set_select_function(sigc::mem_fun(*this, &ResultsTree::onSelectionSelect));
 	// Listen for style changes
+#if GTK_VERSION_LT(3, 0)
 	signal_style_changed().connect_notify(sigc::mem_fun(*this, &ResultsTree::onStyleChanged));
+#else
+	signal_style_updated().connect_notify(sigc::mem_fun(*this, &ResultsTree::onStyleChanged));
+#endif
 
 	// Render the icons
+#if GTK_VERSION_LT(3, 0)
 	m_indexedIconPixbuf = render_icon(Stock::INDEX, ICON_SIZE_MENU, "MetaSE-pinot");
 	m_viewededIconPixbuf = render_icon(Stock::YES, ICON_SIZE_MENU, "MetaSE-pinot");
 	m_upIconPixbuf = render_icon(Stock::GO_UP, ICON_SIZE_MENU, "MetaSE-pinot");
 	m_downIconPixbuf = render_icon(Stock::GO_DOWN, ICON_SIZE_MENU, "MetaSE-pinot");
+#else
+	m_indexedIconPixbuf = render_icon_pixbuf(Stock::INDEX, ICON_SIZE_MENU);
+	m_viewededIconPixbuf = render_icon_pixbuf(Stock::YES, ICON_SIZE_MENU);
+	m_upIconPixbuf = render_icon_pixbuf(Stock::GO_UP, ICON_SIZE_MENU);
+	m_downIconPixbuf = render_icon_pixbuf(Stock::GO_DOWN, ICON_SIZE_MENU);
+#endif
 
 	// Show all
 	show();
@@ -330,7 +357,7 @@ void ResultsTree::onButtonPressEvent(GdkEventButton *ev)
 	else if (ev->type == GDK_2BUTTON_PRESS)
 	{
 #ifdef DEBUG
-		cout << "ResultsTree::onButtonPressEvent: double click on button " << ev->button << endl;
+		clog << "ResultsTree::onButtonPressEvent: double click on button " << ev->button << endl;
 #endif
 		m_signalDoubleClick();
 	}
@@ -368,7 +395,7 @@ bool ResultsTree::onSelectionSelect(const RefPtr<TreeModel>& model,
 			refBuffer->set_text("");
 
 #ifdef DEBUG
-			cout << "ResultsTree::onSelectionSelect: extract for " << row[m_resultsColumns.m_url] << endl;
+			clog << "ResultsTree::onSelectionSelect: extract for " << row[m_resultsColumns.m_url] << endl;
 #endif
 			if (boldPos == ustring::npos)
 			{
@@ -406,16 +433,27 @@ bool ResultsTree::onSelectionSelect(const RefPtr<TreeModel>& model,
 	return true;
 }
 
+#if GTK_VERSION_LT(3, 0)
 void ResultsTree::onStyleChanged(const RefPtr<Style> &previous_style)
+#else
+void ResultsTree::onStyleChanged(void)
+#endif
 {
 #ifdef DEBUG
-	cout << "ResultsTree::onStyleChanged: called" << endl;
+	clog << "ResultsTree::onStyleChanged: called" << endl;
 #endif
 	// FIXME: find better icons :-)
+#if GTK_VERSION_LT(3, 0)
 	m_indexedIconPixbuf = render_icon(Stock::INDEX, ICON_SIZE_MENU, "MetaSE-pinot");
 	m_viewededIconPixbuf = render_icon(Stock::YES, ICON_SIZE_MENU, "MetaSE-pinot");
 	m_upIconPixbuf = render_icon(Stock::GO_UP, ICON_SIZE_MENU, "MetaSE-pinot");
 	m_downIconPixbuf = render_icon(Stock::GO_DOWN, ICON_SIZE_MENU, "MetaSE-pinot");
+#else
+	m_indexedIconPixbuf = render_icon_pixbuf(Stock::INDEX, ICON_SIZE_MENU);
+	m_viewededIconPixbuf = render_icon_pixbuf(Stock::YES, ICON_SIZE_MENU);
+	m_upIconPixbuf = render_icon_pixbuf(Stock::GO_UP, ICON_SIZE_MENU);
+	m_downIconPixbuf = render_icon_pixbuf(Stock::GO_DOWN, ICON_SIZE_MENU);
+#endif
 }
 
 //
@@ -498,15 +536,15 @@ bool ResultsTree::addResults(const string &engineName, const vector<DocumentInfo
 				indexId = indexProps.m_id;
 				engineId = m_settings.getEngineId(m_settings.m_defaultBackend);
 #ifdef DEBUG
-				cout << "ResultsTree::addResults: engine is index " << engineName << " " << indexId << " " << engineId << endl;
+				clog << "ResultsTree::addResults: engine is index " << engineName << " " << indexId << " " << engineId << endl;
 #endif
 			}
 #ifdef DEBUG
-			else cout << "ResultsTree::addResults: " << engineName << " is not an index" <<  endl;
+			else clog << "ResultsTree::addResults: " << engineName << " is not an index" <<  endl;
 #endif
 		}
 #ifdef DEBUG
-		else cout << "ResultsTree::addResults: ID for engine " << engineName << " is " << engineId <<  endl;
+		else clog << "ResultsTree::addResults: ID for engine " << engineName << " is " << engineId <<  endl;
 #endif
 	}
 
@@ -537,7 +575,7 @@ bool ResultsTree::addResults(const string &engineName, const vector<DocumentInfo
 		}
 	}
 #ifdef DEBUG
-	cout << "ResultsTree::addResults: " << resultsList.size() << " results with charset " << charset
+	clog << "ResultsTree::addResults: " << resultsList.size() << " results with charset " << charset
 		<< ", second last run " << secondLastRunTime << endl;
 #endif
 
@@ -574,7 +612,7 @@ bool ResultsTree::addResults(const string &engineName, const vector<DocumentInfo
 			float previousScore = queryHistory.hasItem(m_treeName, engineName,
 				location, oldestScore);
 #ifdef DEBUG
-			cout << "ResultsTree::addResults: " << location << " has scores "
+			clog << "ResultsTree::addResults: " << location << " has scores "
 				<< previousScore << ", " << oldestScore << endl;
 #endif
 			if (previousScore > 0)
@@ -621,7 +659,7 @@ bool ResultsTree::addResults(const string &engineName, const vector<DocumentInfo
 			engineId, indexId, titleIter, groupIter, true) == true)
 		{
 #ifdef DEBUG
-			cout << "ResultsTree::addResults: added row for result " << count
+			clog << "ResultsTree::addResults: added row for result " << count
 				<< ", " << currentScore << ", " << isIndexed << " " << docId
 				<< " " << indexId << endl;
 #endif
@@ -639,7 +677,7 @@ bool ResultsTree::addResults(const string &engineName, const vector<DocumentInfo
 		(updateHistory == true))
 	{
 #ifdef DEBUG
-		cout << "ResultsTree::addResults: removing items for " << m_treeName
+		clog << "ResultsTree::addResults: removing items for " << m_treeName
 			<< ", " << engineName << " older than " << secondLastRunTime << endl;
 #endif
 		queryHistory.deleteItems(m_treeName, engineName, secondLastRunTime);
@@ -648,7 +686,7 @@ bool ResultsTree::addResults(const string &engineName, const vector<DocumentInfo
 	if (count > 0)
 	{
 #ifdef DEBUG
-		cout << "ResultsTree::addResults: " << updatedGroups.size() << " groups to update" << endl;
+		clog << "ResultsTree::addResults: " << updatedGroups.size() << " groups to update" << endl;
 #endif
 		// Update the groups to which we have added results
 		for (std::map<string, TreeModel::iterator>::iterator mapIter = updatedGroups.begin();
@@ -678,7 +716,7 @@ bool ResultsTree::addResults(const string &engineName, const vector<DocumentInfo
 //
 void ResultsTree::setGroupMode(GroupByMode groupMode)
 {
-	ResultsModelColumns::RowType currentType, newType;
+	ResultsModelColumns::RowType newType;
 
 	if (m_groupMode == FLAT)
 	{
@@ -692,7 +730,7 @@ void ResultsTree::setGroupMode(GroupByMode groupMode)
 		return;
 	}
 #ifdef DEBUG
-	cout << "ResultsTree::setGroupMode: set to " << groupMode << endl;
+	clog << "ResultsTree::setGroupMode: set to " << groupMode << endl;
 #endif
 	m_groupMode = groupMode;
 
@@ -707,13 +745,11 @@ void ResultsTree::setGroupMode(GroupByMode groupMode)
 	if (m_groupMode == BY_ENGINE)
 	{
 		// By search engine
-		currentType = ResultsModelColumns::ROW_HOST;
 		newType = ResultsModelColumns::ROW_ENGINE;
 	}
 	else
 	{
 		// By host
-		currentType = ResultsModelColumns::ROW_ENGINE;
 		newType = ResultsModelColumns::ROW_HOST;
 	}
 
@@ -728,7 +764,7 @@ void ResultsTree::setGroupMode(GroupByMode groupMode)
 	{
 		TreeModel::Row row = *iter;
 #ifdef DEBUG
-		cout << "ResultsTree::setGroupMode: looking at " << row[m_resultsColumns.m_url] << endl;
+		clog << "ResultsTree::setGroupMode: looking at " << row[m_resultsColumns.m_url] << endl;
 #endif
 		ResultsModelColumns::RowType type = row[m_resultsColumns.m_resultType];
 		// Skip new type and other rows
@@ -770,7 +806,7 @@ void ResultsTree::setGroupMode(GroupByMode groupMode)
 			{
 				Url urlObj(url);
 #ifdef DEBUG
-				cout << "ResultsTree::setGroupMode: row " << url << endl;
+				clog << "ResultsTree::setGroupMode: row " << url << endl;
 #endif
 				// Add group
 				if (appendGroup(urlObj.getHost(), newType, groupIter) == true)
@@ -797,7 +833,7 @@ void ResultsTree::setGroupMode(GroupByMode groupMode)
 				if (engineNames.empty() == false)
 				{
 #ifdef DEBUG
-					cout << "ResultsTree::setGroupMode: row is for " << engineNames.size() << " engine(s)" << endl;
+					clog << "ResultsTree::setGroupMode: row is for " << engineNames.size() << " engine(s)" << endl;
 #endif
 					// Are there indexes in the list ?
 					set<string>::iterator backendIter = engineNames.find(m_settings.m_defaultBackend);
@@ -807,7 +843,7 @@ void ResultsTree::setGroupMode(GroupByMode groupMode)
 						// Erase this
 						engineNames.erase(backendIter);
 #ifdef DEBUG
-						cout << "ResultsTree::setGroupMode: row is for index(es) " << indexIds << endl;
+						clog << "ResultsTree::setGroupMode: row is for index(es) " << indexIds << endl;
 #endif
 
 						// Add entries for each index name so that we can loop once on engine names
@@ -819,7 +855,7 @@ void ResultsTree::setGroupMode(GroupByMode groupMode)
 							string indexName(*indexIter);
 							engineNames.insert(indexName);
 #ifdef DEBUG
-							cout << "ResultsTree::setGroupMode: row is for index " << indexName << endl;
+							clog << "ResultsTree::setGroupMode: row is for index " << indexName << endl;
 #endif
 						}
 					}
@@ -840,11 +876,11 @@ void ResultsTree::setGroupMode(GroupByMode groupMode)
 								engineId = m_settings.getEngineId(m_settings.m_defaultBackend);
 							}
 #ifdef DEBUG
-							cout << "ResultsTree::setGroupMode: index " << indexId << endl;
+							clog << "ResultsTree::setGroupMode: index " << indexId << endl;
 #endif
 						}
 #ifdef DEBUG
-						else cout << "ResultsTree::setGroupMode: no index" << endl;
+						else clog << "ResultsTree::setGroupMode: no index" << endl;
 #endif
 
 						// Add group
@@ -863,7 +899,7 @@ void ResultsTree::setGroupMode(GroupByMode groupMode)
 								engineId, indexId,
 								newIter, groupIter, true);
 #ifdef DEBUG
-							cout << "ResultsTree::setGroupMode: row for " << engineName << endl;
+							clog << "ResultsTree::setGroupMode: row for " << engineName << endl;
 #endif
 						}
 					}
@@ -908,13 +944,21 @@ void ResultsTree::setGroupMode(GroupByMode groupMode)
 //
 ustring ResultsTree::getFirstSelectionURL(void)
 {
+#if GTK_VERSION_LT(3, 0)
 	list<TreeModel::Path> selectedItems = get_selection()->get_selected_rows();
+#else
+	vector<TreeModel::Path> selectedItems = get_selection()->get_selected_rows();
+#endif
 	if (selectedItems.empty() == true)
 	{
 		return "";
 	}
 
+#if GTK_VERSION_LT(3, 0)
 	list<TreeModel::Path>::iterator itemPath = selectedItems.begin();
+#else
+	vector<TreeModel::Path>::iterator itemPath = selectedItems.begin();
+#endif
 	TreeModel::iterator iter = m_refStore->get_iter(*itemPath);
 	TreeModel::Row row = *iter;
 
@@ -926,15 +970,24 @@ ustring ResultsTree::getFirstSelectionURL(void)
 //
 bool ResultsTree::getSelection(vector<DocumentInfo> &resultsList, bool skipIndexed)
 {
+#if GTK_VERSION_LT(3, 0)
 	list<TreeModel::Path> selectedItems = get_selection()->get_selected_rows();
+#else
+	vector<TreeModel::Path> selectedItems = get_selection()->get_selected_rows();
+#endif
 	if (selectedItems.empty() == true)
 	{
 		return false;
 	}
 
 	// Go through selected items
+#if GTK_VERSION_LT(3, 0)
 	for (list<TreeModel::Path>::iterator itemPath = selectedItems.begin();
 		itemPath != selectedItems.end(); ++itemPath)
+#else
+	for (vector<TreeModel::Path>::iterator itemPath = selectedItems.begin();
+		itemPath != selectedItems.end(); ++itemPath)
+#endif
 	{
 		TreeModel::iterator iter = m_refStore->get_iter(*itemPath);
 		TreeModel::Row row = *iter;
@@ -967,7 +1020,7 @@ bool ResultsTree::getSelection(vector<DocumentInfo> &resultsList, bool skipIndex
 					if (indexProps.m_internal == true)
 					{
 #ifdef DEBUG
-						cout << "ResultsTree::getSelection: result in internal index " << *indexIter << endl;
+						clog << "ResultsTree::getSelection: result in internal index " << *indexIter << endl;
 #endif
 						current.setIsIndexed(indexProps.m_id, row[m_resultsColumns.m_docId]);
 						break;
@@ -979,7 +1032,7 @@ bool ResultsTree::getSelection(vector<DocumentInfo> &resultsList, bool skipIndex
 		}
 	}
 #ifdef DEBUG
-	cout << "ResultsTree::getSelection: " << resultsList.size() << " results selected" << endl;
+	clog << "ResultsTree::getSelection: " << resultsList.size() << " results selected" << endl;
 #endif
 
 	return true;
@@ -990,15 +1043,24 @@ bool ResultsTree::getSelection(vector<DocumentInfo> &resultsList, bool skipIndex
 //
 void ResultsTree::setSelectionState(bool viewed)
 {
+#if GTK_VERSION_LT(3, 0)
 	list<TreeModel::Path> selectedItems = get_selection()->get_selected_rows();
+#else
+	vector<TreeModel::Path> selectedItems = get_selection()->get_selected_rows();
+#endif
 	if (selectedItems.empty() == true)
 	{
 		return;
 	}
 
 	// Go through selected items
+#if GTK_VERSION_LT(3, 0)
 	for (list<TreeModel::Path>::iterator itemPath = selectedItems.begin();
 		itemPath != selectedItems.end(); ++itemPath)
+#else
+	for (vector<TreeModel::Path>::iterator itemPath = selectedItems.begin();
+		itemPath != selectedItems.end(); ++itemPath)
+#endif
 	{
 		TreeModel::iterator iter = m_refStore->get_iter(*itemPath);
 		TreeModel::Row row = *iter;
@@ -1061,8 +1123,13 @@ bool ResultsTree::deleteSelection(void)
 	bool empty = false;
 
 	// Go through selected items
+#if GTK_VERSION_LT(3, 0)
 	list<TreeModel::Path> selectedItems = get_selection()->get_selected_rows();
 	list<TreeModel::Path>::iterator itemPath = selectedItems.begin();
+#else
+	vector<TreeModel::Path> selectedItems = get_selection()->get_selected_rows();
+	vector<TreeModel::Path>::iterator itemPath = selectedItems.begin();
+#endif
 	while (itemPath != selectedItems.end())
 	{
 		TreeModel::iterator iter = m_refStore->get_iter(*itemPath);
@@ -1080,7 +1147,7 @@ bool ResultsTree::deleteSelection(void)
 			{
 				m_resultsGroups.erase(mapIter);
 #ifdef DEBUG
-				cout << "ResultsTree::deleteSelection: erased group " << groupName << endl;
+				clog << "ResultsTree::deleteSelection: erased group " << groupName << endl;
 #endif
 			}
 		}
@@ -1179,7 +1246,7 @@ bool ResultsTree::deleteResults(const string &engineName)
 	{
 		onSelectionChanged();
 #ifdef DEBUG
-		cout << "ResultsTree::deleteResults: erased " << count << " rows" << endl;
+		clog << "ResultsTree::deleteResults: erased " << count << " rows" << endl;
 #endif
 		return true;
 	}
@@ -1308,7 +1375,7 @@ void ResultsTree::exportResults(const string &fileName,
 		maxResultsCount += groupChildren.size();
 	}
 #ifdef DEBUG
-	cout << "ResultsTree::exportResults: " << maxResultsCount << " results to export" << endl;
+	clog << "ResultsTree::exportResults: " << maxResultsCount << " results to export" << endl;
 #endif
 
 	// Start
@@ -1366,7 +1433,7 @@ void ResultsTree::exportResults(TreeModel::Children &groupChildren,
 		unsigned int indexIds = childRow[m_resultsColumns.m_indexes];
 
 #ifdef DEBUG
-		cout << "ResultsTree::exportResults: engines " << engineIds << ", indexes " << indexIds << endl;
+		clog << "ResultsTree::exportResults: engines " << engineIds << ", indexes " << indexIds << endl;
 #endif
 		result.deserialize(serial);
 		m_settings.getEngineNames(engineIds, engineNames);
@@ -1432,7 +1499,7 @@ bool ResultsTree::appendResult(const ustring &text, const ustring &url,
 	if (!parentIter)
 	{
 #ifdef DEBUG
-		cout << "ResultsTree::appendResult: no parent" << endl;
+		clog << "ResultsTree::appendResult: no parent" << endl;
 #endif
 		newRowIter = m_refStore->append();
 	}
@@ -1501,7 +1568,7 @@ bool ResultsTree::appendGroup(const string &groupName, ResultsModelColumns::RowT
 		m_resultsGroups[groupName] = groupIter;
 		success = true;
 #ifdef DEBUG
-		cout << "ResultsTree::appendGroup: updated map with " << groupName << endl;
+		clog << "ResultsTree::appendGroup: updated map with " << groupName << endl;
 #endif
 	}
 	else
@@ -1509,7 +1576,7 @@ bool ResultsTree::appendGroup(const string &groupName, ResultsModelColumns::RowT
 		// Yes, it is
 		groupIter = mapIter->second;
 #ifdef DEBUG
-		cout << "ResultsTree::appendGroup: found " << groupName << " in map" << endl;
+		clog << "ResultsTree::appendGroup: found " << groupName << " in map" << endl;
 #endif
 		success = true;
 	}
@@ -1591,13 +1658,13 @@ void ResultsTree::updateRow(TreeModel::Row &row, const ustring &text,
 	catch (Error &error)
 	{
 #ifdef DEBUG
-		cout << "ResultsTree::updateRow: " << error.what() << endl;
+		clog << "ResultsTree::updateRow: " << error.what() << endl;
 #endif
 	}
 	catch (...)
 	{
 #ifdef DEBUG
-		cout << "ResultsTree::updateRow: caught unknown exception" << endl;
+		clog << "ResultsTree::updateRow: caught unknown exception" << endl;
 #endif
 	}
 }
@@ -1615,7 +1682,7 @@ ustring ResultsTree::findResultsExtract(const Gtk::TreeModel::Row &row)
 	unsigned int indexIds = row[m_resultsColumns.m_indexes];
 
 #ifdef DEBUG
-	cout << "ResultsTree::findResultsExtract: " << url << " has engines " << engineIds << ", indexes " << indexIds << endl;
+	clog << "ResultsTree::findResultsExtract: " << url << " has engines " << engineIds << ", indexes " << indexIds << endl;
 #endif
 	m_settings.getEngineNames(engineIds, engineNames);
 	for (set<string>::const_iterator engineIter = engineNames.begin();
@@ -1641,7 +1708,7 @@ ustring ResultsTree::findResultsExtract(const Gtk::TreeModel::Row &row)
 			engineName = (*indexNames.begin());
 
 #ifdef DEBUG
-			cout << "ResultsTree::findResultsExtract: engine or index " << engineName << endl;
+			clog << "ResultsTree::findResultsExtract: engine or index " << engineName << endl;
 #endif
 			extract = queryHistory.getItemExtract(from_utf8(m_treeName), engineName, url);
 			if (extract.empty() == false)
