@@ -1,5 +1,5 @@
 /*
- *  Copyright 2008-2010 Fabrice Colin
+ *  Copyright 2008-2012 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -116,7 +116,7 @@ class GetLabelsThread : public WorkerThread
 						inserter(labels, labels.begin()));
 				}
 #ifdef DEBUG
-				else cout << "GetLabelsThread::doWork: relying on configuration file" << endl;
+				else clog << "GetLabelsThread::doWork: relying on configuration file" << endl;
 #endif
 
 				delete pDaemonIndex;
@@ -130,7 +130,7 @@ class GetLabelsThread : public WorkerThread
 };
 
 prefsWindow::InternalState::InternalState(prefsWindow *pWindow) :
-        ThreadsManager(PinotSettings::getInstance().m_docsIndexLocation),
+        QueueManager(PinotSettings::getInstance().m_docsIndexLocation),
 	m_savedPrefs(false)
 {
         m_onThreadEndSignal.connect(sigc::mem_fun(*pWindow, &prefsWindow::on_thread_end));
@@ -174,7 +174,7 @@ prefsWindow::prefsWindow() :
 		guint rowsCount = rowsProp.get_value();
 
 #ifdef DEBUG
-		cout << "prefsWindow: adding " << m_settings.m_editablePluginValues.size() << " more rows" << endl;
+		clog << "prefsWindow: adding " << m_settings.m_editablePluginValues.size() << " more rows" << endl;
 #endif
 		generalTable->resize(rowsCount + m_settings.m_editablePluginValues.size(), columnsProp.get_value());
 
@@ -278,7 +278,7 @@ void prefsWindow::updateLabelRow(const ustring &path_string, const ustring &text
 		TreeRow row = *iter;
 
 #ifdef DEBUG
-		cout << "prefsWindow::updateLabelRow: set label to " << text << endl;
+		clog << "prefsWindow::updateLabelRow: set label to " << text << endl;
 #endif
 		// Set the value of the name column
 		row.set_value(m_labelsColumns.m_name, (ustring)text);
@@ -333,7 +333,7 @@ void prefsWindow::on_thread_end(WorkerThread *pThread)
 	if (status.empty() == false)
 	{
 #ifdef DEBUG
-		cout << "prefsWindow::on_thread_end: " << status << endl;
+		clog << "prefsWindow::on_thread_end: " << status << endl;
 #endif
 		// FIXME: tell the user the thread failed
 	}
@@ -369,7 +369,7 @@ void prefsWindow::on_thread_end(WorkerThread *pThread)
 	else
 	{
 #ifdef DEBUG
-		cout << "prefsWindow::on_thread_end: quitting" << endl;
+		clog << "prefsWindow::on_thread_end: quitting" << endl;
 #endif
 		on_prefsWindow_delete_event(NULL);
 	}
@@ -392,7 +392,11 @@ void prefsWindow::attach_value_widgets(const string &name, const string &value,
 	valueLabel->set_angle(0);
 	valueLabel->set_single_line_mode(false);
 
+#if GTK_VERSION_LT(3, 0)
 	valueEntry->set_flags(Gtk::CAN_FOCUS);
+#else
+	valueEntry->set_can_focus();
+#endif
 	valueEntry->set_visibility(true);
 	valueEntry->set_editable(true);
 	valueEntry->set_max_length(0);
@@ -412,9 +416,15 @@ void prefsWindow::attach_value_widgets(const string &name, const string &value,
 
 void prefsWindow::populate_proxyTypeCombobox()
 {
+#if GTK_VERSION_LT(3, 0)
 	proxyTypeCombobox->append_text("HTTP");
 	proxyTypeCombobox->append_text("SOCKS v4");
 	proxyTypeCombobox->append_text("SOCKS v5");
+#else
+	proxyTypeCombobox->append("HTTP");
+	proxyTypeCombobox->append("SOCKS v4");
+	proxyTypeCombobox->append("SOCKS v5");
+#endif
 }
 
 void prefsWindow::populate_labelsTreeview()
@@ -479,7 +489,7 @@ void prefsWindow::save_labelsTreeview()
 			}
 
 #ifdef DEBUG
-			cout << "prefsWindow::save_labelsTreeview: " << labelName << endl;
+			clog << "prefsWindow::save_labelsTreeview: " << labelName << endl;
 #endif
 			// Add this new label to the settings
 			labels.insert(labelName);
@@ -549,7 +559,7 @@ bool prefsWindow::save_directoriesTreeview()
 			}
 
 #ifdef DEBUG
-			cout << "prefsWindow::save_directoriesTreeview: " << indexableLocation.m_name << endl;
+			clog << "prefsWindow::save_directoriesTreeview: " << indexableLocation.m_name << endl;
 #endif
 			m_settings.m_indexableLocations.insert(indexableLocation);
 			dirsString += indexableLocation.m_name + (indexableLocation.m_monitor == true ? "1" : "0") + "|";
@@ -559,7 +569,7 @@ bool prefsWindow::save_directoriesTreeview()
 	if (m_directoriesHash != StringManip::hashString(dirsString))
 	{
 #ifdef DEBUG
-		cout << "prefsWindow::save_directoriesTreeview: directories changed" << endl;
+		clog << "prefsWindow::save_directoriesTreeview: directories changed" << endl;
 #endif
 		return true;
 	}
@@ -569,8 +579,13 @@ bool prefsWindow::save_directoriesTreeview()
 
 void prefsWindow::populate_patternsCombobox()
 {
+#if GTK_VERSION_LT(3, 0)
 	patternsCombobox->append_text(_("Exclude these patterns from indexing"));
 	patternsCombobox->append_text(_("Only index these patterns"));
+#else
+	patternsCombobox->append(_("Exclude these patterns from indexing"));
+	patternsCombobox->append(_("Only index these patterns"));
+#endif
 }
 
 void prefsWindow::populate_patternsTreeview(const set<ustring> &patternsList, bool isBlackList)
@@ -656,7 +671,7 @@ bool prefsWindow::save_patternsTreeview()
 	if (m_patternsHash != StringManip::hashString(patternsString))
 	{
 #ifdef DEBUG
-		cout << "prefsWindow::save_patternsTreeview: patterns changed" << endl;
+		clog << "prefsWindow::save_patternsTreeview: patterns changed" << endl;
 #endif
 		return true;
 	}
@@ -772,7 +787,7 @@ void prefsWindow::on_addDirectoryButton_clicked()
 	if (select_file_name(_("Directory to index"), dirName, true, true) == true)
 	{
 #ifdef DEBUG
-		cout << "prefsWindow::on_addDirectoryButton_clicked: "
+		clog << "prefsWindow::on_addDirectoryButton_clicked: "
 			<< dirName << endl;
 #endif
 		// Create a new entry in the directories list
