@@ -1,5 +1,5 @@
 /*
- *  Copyright 2005-2010 Fabrice Colin
+ *  Copyright 2005-2012 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -80,7 +80,7 @@ class DaemonStatusThread : public WorkerThread
 				m_gotStats = true;
 			}
 #ifdef DEBUG
-			else cout << "DaemonStatusThread::doWork: failed to get statistics" << endl;
+			else clog << "DaemonStatusThread::doWork: failed to get statistics" << endl;
 #endif
 		}
 
@@ -92,7 +92,7 @@ class DaemonStatusThread : public WorkerThread
 #endif
 
 statisticsDialog::InternalState::InternalState(statisticsDialog *pWindow) :
-        ThreadsManager(PinotSettings::getInstance().m_docsIndexLocation),
+        QueueManager(PinotSettings::getInstance().m_docsIndexLocation),
 	m_getStats(true),
 	m_gettingStats(false),
 	m_lowDiskSpace(false),
@@ -478,7 +478,7 @@ void statisticsDialog::on_thread_end(WorkerThread *pThread)
 	if (status.empty() == false)
 	{
 #ifdef DEBUG
-		cout << "statisticsDialog::on_thread_end: " << status << endl;
+		clog << "statisticsDialog::on_thread_end: " << status << endl;
 #endif
 		success = false;
 	}
@@ -502,7 +502,7 @@ void statisticsDialog::on_thread_end(WorkerThread *pThread)
 				m_state.m_onBattery = pStatusThread->m_onBattery;
 				m_state.m_crawling = pStatusThread->m_crawling;
 #ifdef DEBUG
-				cout << "statisticsDialog::on_thread_end: refreshed stats" << endl;
+				clog << "statisticsDialog::on_thread_end: refreshed stats" << endl;
 #endif
 			}
 		}
