@@ -109,7 +109,7 @@ static time_t mktime_from_utc (struct tm *t)
 
 #include "TimeConverter.h"
 
-using std::cout;
+using std::clog;
 using std::endl;
 using std::string;
 
@@ -137,14 +137,23 @@ string TimeConverter::toTimestamp(time_t aTime, bool inGMTime)
 		)
 	{
 		char timeStr[64];
+		size_t formattedSize = 0;
 
-		// FIXME: don't use this extension ?
+		if (inGMTime == true)
+		{
+			formattedSize = strftime(timeStr, 64, "%a, %d %b %Y %H:%M:%S GMT", pTimeTm);
+		}
+		else
+		{
+			// FIXME: don't use this extension ?
 #if defined(__GNU_LIBRARY__)
-		// %z is a GNU extension
-		if (strftime(timeStr, 64, "%a, %d %b %Y %H:%M:%S %z", pTimeTm) > 0)
+			// %z is a GNU extension
+			formattedSize = strftime(timeStr, 64, "%a, %d %b %Y %H:%M:%S %z", pTimeTm);
 #else
-		if (strftime(timeStr, 64, "%a, %d %b %Y %H:%M:%S %Z", pTimeTm) > 0)
+			formattedSize = strftime(timeStr, 64, "%a, %d %b %Y %H:%M:%S %Z", pTimeTm);
 #endif
+		}
+		if (formattedSize > 0)
 		{
 			delete pTimeTm;
 
@@ -231,7 +240,7 @@ time_t TimeConverter::fromYYYYMMDDString(const string &yyyymmdd, bool inGMTime)
 	timeTm.tm_mday = atoi(yyyymmdd.substr(6, 2).c_str());
 #endif
 #ifdef DEBUG
-	cout << "TimeConverter::fromYYYYMMDDString: " << timeTm.tm_year << " " << timeTm.tm_mon << " " << timeTm.tm_mday << endl;
+	clog << "TimeConverter::fromYYYYMMDDString: " << timeTm.tm_year << " " << timeTm.tm_mon << " " << timeTm.tm_mday << endl;
 #endif
 	if (inGMTime == true)
 	{
@@ -301,7 +310,7 @@ time_t TimeConverter::fromHHMMSSString(const string &hhmmss, bool inGMTime)
 	timeTm.tm_sec = atoi(hhmmss.substr(4, 2).c_str());
 #endif
 #ifdef DEBUG
-	cout << "TimeConverter::fromHHMMSSString: " << timeTm.tm_hour << " " << timeTm.tm_min << " " << timeTm.tm_sec << endl;
+	clog << "TimeConverter::fromHHMMSSString: " << timeTm.tm_hour << " " << timeTm.tm_min << " " << timeTm.tm_sec << endl;
 #endif
 	if (inGMTime == true)
 	{
