@@ -53,11 +53,9 @@ void Timer::start(void)
 }
 
 /// Stops the timer and returns the number of milliseconds elapsed.
-suseconds_t Timer::stop(void)
+long Timer::stop(void)
 {
 	gettimeofday(&m_stop, NULL);
 
-	suseconds_t timeDiff = (((m_stop.tv_sec - m_start.tv_sec) * 1000) + ((m_stop.tv_usec - m_start.tv_usec) / 1000));
-
-	return timeDiff;
+	return (long)(((m_stop.tv_sec - m_start.tv_sec) * 1000) + ((m_stop.tv_usec - m_start.tv_usec) / 1000));
 }
